SegmentCursor

Struct SegmentCursor 

pub struct SegmentCursor { /* private fields */ }
Available on crate feature std only.
A subscribed reader of a Trunk’s segment log. Obtained via Trunk::subscribe_segments (ordinary, lossy-on-overflow) or Trunk::pin_segments (pinning, ArchiveOverrun-governed) — read those methods’ docs, and The DVR contradiction, before creating more than a handful of these.

Implementations

Source

impl SegmentCursor

pub fn poll(&mut self) -> Option<SegmentCursorItem>

Pull the next item, if any is ready.

Loss is always reported before further data, in the same Option<SegmentCursorItem> as real segments — the same cannot-be-skipped-past precedent as SampleCursor::poll/ crate::byte_tap::TapItem.